function gsiocobjdisconnect(serialObject)
% GSIOCOBJDISCONNECT terminates communication with GSIOC devices
% gsiocobjdisconnect(serialObject) terminates communication with GSIOC
% devices, given serialObject as a valid pump serial object (generated by
% gsiocobj).

% e.g. gsiocobjdisconnect(serialObject) - terminates communication with the
% GSIOC device, then deletes and clears the serial object

% Range:

% serialObject = valid serial port object


% checks the number of arguments
error(nargchk(1, 1, nargin))

% error handling
if ~isa(serialObject, 'serial') || ~isvalid(serialObject) || ~strcmp(serialObject.Status, 'open')
    % errors if not a valid serial object or is closed
    error('serialObject must be a valid open serial object.')
end

% closes communication
fclose(serialObject)

% deletes it afterwards
delete(serialObject)